==> aldo-0.6.1.tar.bz2: aldo-0.6.1/src/resources.h <==
// -*- C++ -*-
/***************************************************************************
                                 Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : denever@users.sourceforge.net
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#define chkmsg_3  "This is what you should've copied down."
#define chkmsg_4  "If you didn't copy down a char or number put @"
#define chkmsg_2  "% of the exercise is right."
#define chkmsg_1  "Now insert chars that you caught."

#define errmsg_noformat   "Configuration file is incorrectly formatted"
#define errmsg_overwrite  "You have tried to overwrite configuration file"
#define errmsg_nooption   "Can't find an option in configuration file"
#define errmsg_nosection  "Can't find the section in configuration file"
#define errmsg_noopenfile "Can't open configuration file"
#define errmsg_nofile     "Configuration file doesn't exist"
#define errmsg_conf       "Select Default Settings in Setup menu"

#define main_menu_title  "Main Menu of Aldo"
#define main_menu_prompt "Your choice: "
#define main_menu_item1  "Classic"
#define main_menu_item2  "Koch method"
#define main_menu_item3  "Read from file"
#define main_menu_item4  "Callsigns"
#define main_menu_item5  "Setup"
#define main_menu_item6  "Exit"

#define msg_start      "About to start keying. Get ready..."
#define msg_changes    "Change these settings from configure menu."
#define msg_speed      "Keying speed: "
#define msg_strlen     "String length: "
#define msg_skill      "This it training character set: "
#define msg_strnum     "Number of strings: "
#define msg_callformat "Template callsign: "

#define dlg_skill_title   "Select training character set"
#define dlg_skill_choice1 "e,i,s,h,t,m,o"
#define dlg_skill_choice2 "e,i,s,h,t,m,o,a,j,w,v,u"
#define dlg_skill_choice3 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g"
#define dlg_skill_choice4 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g,r,p,l,f"
#define dlg_skill_choice5 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g,r,p,l,f,k,c,y,q,z,x"
#define dlg_skill_choice6 "All chars and numbers"
#define dlg_skill_choice7 "Custom character set"

#define dlg_skill2_title    "Add a group or option to your exercise:"
#define dlg_skill2_choice1  "e,i,s,h,t,m,o"
#define dlg_skill2_choice2  "a,w,j,v,u"
#define dlg_skill2_choice3  "n,d,b,g"
#define dlg_skill2_choice4  "r,p,l,f"
#define dlg_skill2_choice5  "k,c,y,q,z,x"
#define dlg_skill2_choice6  "0123456789"
#define dlg_skill2_choice7  "Chars ordered "
#define dlg_skill2_choice8  "Chars submixed with group order "
#define dlg_skill2_choice9  "Chars mixed without group order "
#define dlg_skill2_choice10 "End"

#define dlg_koch_title    "Do you want to continue with the Koch method?"
#define dlg_koch_continue "Yes"
#define dlg_koch_exit     "No"

#define insert_device     "Insert soundcard device file"
#define insert_samplerate "Insert sample rate"
#define insert_samplesize "Insert sample size"

#define insert_beginpause "Insert pause before keying in seconds [2]"
#define insert_charpause  "Insert length of space between chars in number of dots [3]"
#define insert_strpause   "Insert length of space between words in number of dots [7]"
#define insert_dotlen     "Insert dot length  [1]"
#define insert_linelen    "Insert line length [3]"
#define insert_tone       "Insert tone of buzzer in Hz [900]"

#define insert_wpm        "Insert keying speed in words per minute"
#define insert_strlen     "Insert length of strings"
#define insert_filename   "Insert name of file to read"
#define insert_strnum     "Number of strings to send"
#define insert_callformat "Insert now a template of Callsign"

#define conf_menu_title "Setup Menu"
#define conf_menu_item1 "Soundcard Setup"
#define conf_menu_item2 "Keyer Setup"
#define conf_menu_item3 "Classic Setup"
#define conf_menu_item4 "Koch method Setup"
#define conf_menu_item5 "Qrz exercise Setup"
#define conf_menu_item6 "Default Settings"
#define conf_menu_item7 "Return to Main Menu"

==> aldo-0.6.3.tar.bz2: aldo-0.6.3/src/resources.h <==
// -*- C++ -*-
/***************************************************************************
                                 Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : denever@users.sourceforge.net
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#define chkmsg_3  "This is what you should have copied down."
#define chkmsg_4  "If you didn't copy down a char or number put @"
#define chkmsg_2  "% of the exercise is right."
#define chkmsg_1  "Now insert the characters that you caught:"

#define errmsg_noformat   "Configuration file is incorrectly formatted"
#define errmsg_overwrite  "You have tried to overwrite the configuration file"
#define errmsg_nooption   "Can't find an option in the configuration file"
#define errmsg_nosection  "Can't find section in the configuration file"
#define errmsg_noopenfile "Can't open the configuration file"
#define errmsg_nofile     "The configuration file doesn't exist"
#define errmsg_conf       "Select Default Settings in the Setup Menu"

#define main_menu_title  "Aldo Main Menu"
#define main_menu_prompt "Your choice: "
#define main_menu_item1  "Classic"
#define main_menu_item2  "Koch method"
#define main_menu_item3  "Read from file"
#define main_menu_item4  "Callsigns"
#define main_menu_item5  "Setup"
#define main_menu_item6  "Exit"

#define msg_start      "About to start keying. Get ready..."
#define msg_changes    "Change these settings from the Setup Menu."
#define msg_speed      "Keying speed: "
#define msg_strlen     "String length: "
#define msg_skill      "Training character set: "
#define msg_strnum     "Number of strings: "
#define msg_callformat "Template callsign: "

#define dlg_skill_title   "Select training character set"
#define dlg_skill_choice1 "e,i,s,h,t,m,o"
#define dlg_skill_choice2 "e,i,s,h,t,m,o,a,j,w,v,u"
#define dlg_skill_choice3 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g"
#define dlg_skill_choice4 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g,r,p,l,f"
#define dlg_skill_choice5 "e,i,s,h,t,m,o,a,w,j,u,v,n,d,b,g,r,p,l,f,k,c,y,q,z,x"
#define dlg_skill_choice6 "All chars and numbers"
#define dlg_skill_choice7 "Custom character set"

#define dlg_skill2_title    "Add a group or option to your exercise:"
#define dlg_skill2_choice1  "e,i,s,h,t,m,o"
#define dlg_skill2_choice2  "a,w,j,v,u"
#define dlg_skill2_choice3  "n,d,b,g"
#define dlg_skill2_choice4  "r,p,l,f"
#define dlg_skill2_choice5  "k,c,y,q,z,x"
#define dlg_skill2_choice6  "0123456789"
#define dlg_skill2_choice7  "Chars ordered "
#define dlg_skill2_choice8  "Chars submixed with group order "
#define dlg_skill2_choice9  "Chars mixed without group order "
#define dlg_skill2_choice10 "End"

#define dlg_koch_title    "Do you want to continue with the Koch method?"
#define dlg_koch_continue "Yes"
#define dlg_koch_exit     "No"

#define insert_device     "Soundcard device file"
#define insert_samplerate "Sample rate"
#define insert_samplesize "Sample size"

#define insert_beginpause "Pause before keying (seconds): [2]"
#define insert_charpause  "Length of space between two characters in a word (number of dots): [3]"
#define insert_strpause   "Length of space between two words (number of dots): [7]"
#define insert_dotlen     "Dit length  [1]"
#define insert_linelen    "Dah length [3]"
#define insert_tone       "Frequency of buzzer (Hz): [900]"

#define insert_wpm        "Keying speed (words per minute):"
#define insert_strlen     "Length of strings"
#define insert_filename   "Name of file to read"
#define insert_strnum     "Number of strings to send"
#define insert_callformat "Enter callsign template"

#define conf_menu_title "Setup Menu"
#define conf_menu_item1 "Soundcard Setup"
#define conf_menu_item2 "Keyer Setup"
#define conf_menu_item3 "Classic Setup"
#define conf_menu_item4 "Koch method Setup"
#define conf_menu_item5 "Qrz exercise Setup"
#define conf_menu_item6 "Default Settings"
#define conf_menu_item7 "Return to Main Menu"
